==> haskell-postgresql-libpq-0.9.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-libpq
version: 0.9.3.1
id: postgresql-libpq-0.9.3.1-2uyCt1bjp2BBNrJ77pyQ3o
key: postgresql-libpq-0.9.3.1-2uyCt1bjp2BBNrJ77pyQ3o
license: BSD3
copyright: (c) 2010 Grant Monroe
           (c) 2011 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
homepage: http://github.com/lpsmith/postgresql-libpq
synopsis: low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.
category: Database
author: Grant Monroe, Leon P Smith, Joey Adams
exposed: True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal
abi: 958d67e991242d5e9ff37a74ca40bcef
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/postgresql-libpq-0.9.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/postgresql-libpq-0.9.3.1
              /usr/lib
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2 /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/postgresql-libpq-0.9.3.1
hs-libraries: HSpostgresql-libpq-0.9.3.1-2uyCt1bjp2BBNrJ77pyQ3o
extra-libraries:
    pq
include-dirs: /usr/include
depends:
    base-4.9.1.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock
haddock-html: /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-libpq-0.9.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-libpq
version: 0.9.3.1
id: postgresql-libpq-0.9.3.1-CXlU41KFsMy8E9CIoEe7GF
key: postgresql-libpq-0.9.3.1-CXlU41KFsMy8E9CIoEe7GF
license: BSD3
copyright: (c) 2010 Grant Monroe
           (c) 2011 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
homepage: http://github.com/lpsmith/postgresql-libpq
synopsis: low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.
category: Database
author: Grant Monroe, Leon P Smith, Joey Adams
exposed: True
indefinite: False
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal
abi: 444bb6d65b01342e36cb4f706b6179e1
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-libpq-0.9.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-libpq-0.9.3.1
              /usr/lib
dynamic-library-dirs: /usr/lib /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/postgresql-libpq-0.9.3.1
hs-libraries: HSpostgresql-libpq-0.9.3.1-CXlU41KFsMy8E9CIoEe7GF
extra-libraries:
    pq
include-dirs: /usr/include
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock
haddock-html: /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
